@@ -8,11 +8,11 @@ from django.db.models.base import ModelBase
 from django.utils import tree
 from django.utils.encoding import force_str
 
-from codex._vendor.haystack.constants import DEFAULT_ALIAS, FILTER_SEPARATOR, VALID_FILTERS
-from codex._vendor.haystack.exceptions import FacetingError, MoreLikeThisError
-from codex._vendor.haystack.models import SearchResult
-from codex._vendor.haystack.utils import get_model_ct
-from codex._vendor.haystack.utils.loading import UnifiedIndex
+from ...haystack.constants import DEFAULT_ALIAS, FILTER_SEPARATOR, VALID_FILTERS
+from ...haystack.exceptions import FacetingError, MoreLikeThisError
+from ...haystack.models import SearchResult
+from ...haystack.utils import get_model_ct
+from ...haystack.utils.loading import UnifiedIndex
 
 VALID_GAPS = ["year", "month", "day", "hour", "minute", "second"]
 
@@ -34,7 +34,7 @@ def log_query(func):
             stop = time()
 
             if settings.DEBUG:
-                from codex._vendor.haystack import connections
+                from ...haystack import connections
 
                 connections[obj.connection_alias].queries.append(
                     {
@@ -212,7 +212,7 @@ class BaseSearchBackend:
         any results that are not currently handled models and ensures
         consistent caching.
         """
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         models = []
 
@@ -504,7 +504,7 @@ class BaseSearchQuery:
         self.spelling_query = None
         self.result_class = SearchResult
         self.stats = {}
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         self._using = using
         self.backend = connections[self._using].get_backend()
@@ -520,7 +520,7 @@ class BaseSearchQuery:
 
     def __setstate__(self, obj_dict):
         """For unpickling."""
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         self.__dict__.update(obj_dict)
         self.backend = connections[self._using].get_backend()
@@ -906,7 +906,7 @@ class BaseSearchQuery:
 
     def add_within(self, field, point_1, point_2):
         """Adds bounding box parameters to search query."""
-        from codex._vendor.haystack.utils.geo import ensure_point
+        from ...haystack.utils.geo import ensure_point
 
         self.within = {
             "field": field,
@@ -916,7 +916,7 @@ class BaseSearchQuery:
 
     def add_dwithin(self, field, point, distance):
         """Adds radius-based parameters to search query."""
-        from codex._vendor.haystack.utils.geo import ensure_distance, ensure_point
+        from ...haystack.utils.geo import ensure_distance, ensure_point
 
         self.dwithin = {
             "field": field,
@@ -929,13 +929,13 @@ class BaseSearchQuery:
         Denotes that results should include distance measurements from the
         point passed in.
         """
-        from codex._vendor.haystack.utils.geo import ensure_point
+        from ...haystack.utils.geo import ensure_point
 
         self.distance_point = {"field": field, "point": ensure_point(point)}
 
     def add_field_facet(self, field, **options):
         """Adds a regular facet on a field."""
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         field_name = (
             connections[self._using].get_unified_index().get_facet_fieldname(field)
@@ -944,7 +944,7 @@ class BaseSearchQuery:
 
     def add_date_facet(self, field, start_date, end_date, gap_by, gap_amount=1):
         """Adds a date-based facet on a field."""
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         if gap_by not in VALID_GAPS:
             raise FacetingError(
@@ -964,7 +964,7 @@ class BaseSearchQuery:
 
     def add_query_facet(self, field, query):
         """Adds a query facet on a field."""
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         self.query_facets.append(
             (
@@ -995,7 +995,7 @@ class BaseSearchQuery:
 
     def post_process_facets(self, results):
         # Handle renaming the facet fields. Undecorate and all that.
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         revised_facets = {}
         field_data = connections[self._using].get_unified_index().all_searchfields()
@@ -1039,7 +1039,7 @@ class BaseSearchQuery:
         if using is None:
             using = self._using
         else:
-            from codex._vendor.haystack import connections
+            from ...haystack import connections
 
             klass = connections[using].query
 
