@@ -3,15 +3,15 @@ import warnings
 
 from django.conf import settings
 
-from codex._vendor. import haystack
-from codex._vendor.haystack.backends import BaseEngine
-from codex._vendor.haystack.backends.elasticsearch_backend import (
+from ... import haystack
+from ...haystack.backends import BaseEngine
+from ...haystack.backends.elasticsearch_backend import (
     ElasticsearchSearchBackend,
     ElasticsearchSearchQuery,
 )
-from codex._vendor.haystack.constants import DEFAULT_OPERATOR, DJANGO_CT, DJANGO_ID, FUZZINESS
-from codex._vendor.haystack.exceptions import MissingDependency
-from codex._vendor.haystack.utils import get_identifier, get_model_ct
+from ...haystack.constants import DEFAULT_OPERATOR, DJANGO_CT, DJANGO_ID, FUZZINESS
+from ...haystack.exceptions import MissingDependency
+from ...haystack.utils import get_identifier, get_model_ct
 
 try:
     import elasticsearch
@@ -375,7 +375,7 @@ class Elasticsearch7SearchBackend(ElasticsearchSearchBackend):
         }
 
     def _build_search_query_within(self, within):
-        from codex._vendor.haystack.utils.geo import generate_bounding_box
+        from ...haystack.utils.geo import generate_bounding_box
 
         ((south, west), (north, east)) = generate_bounding_box(
             within["point_1"], within["point_2"]
@@ -400,7 +400,7 @@ class Elasticsearch7SearchBackend(ElasticsearchSearchBackend):
         result_class=None,
         **kwargs
     ):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         if not self.setup_complete:
             self.setup()
