@@ -5,9 +5,9 @@ from datetime import datetime, timedelta
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 
-from codex._vendor. import haystack
-from codex._vendor.haystack.backends import BaseEngine, BaseSearchBackend, BaseSearchQuery, log_query
-from codex._vendor.haystack.constants import (
+from ... import haystack
+from ...haystack.backends import BaseEngine, BaseSearchBackend, BaseSearchQuery, log_query
+from ...haystack.constants import (
     ALL_FIELD,
     DEFAULT_OPERATOR,
     DJANGO_CT,
@@ -16,12 +16,12 @@ from codex._vendor.haystack.constants import (
     FUZZY_MIN_SIM,
     ID,
 )
-from codex._vendor.haystack.exceptions import MissingDependency, MoreLikeThisError, SkipDocument
-from codex._vendor.haystack.inputs import Clean, Exact, PythonData, Raw
-from codex._vendor.haystack.models import SearchResult
-from codex._vendor.haystack.utils import get_identifier, get_model_ct
-from codex._vendor.haystack.utils import log as logging
-from codex._vendor.haystack.utils.app_loading import haystack_get_model
+from ...haystack.exceptions import MissingDependency, MoreLikeThisError, SkipDocument
+from ...haystack.inputs import Clean, Exact, PythonData, Raw
+from ...haystack.models import SearchResult
+from ...haystack.utils import get_identifier, get_model_ct
+from ...haystack.utils import log as logging
+from ...haystack.utils.app_loading import haystack_get_model
 
 try:
     import elasticsearch
@@ -509,7 +509,7 @@ class ElasticsearchSearchBackend(BaseSearchBackend):
             )
 
         if within is not None:
-            from codex._vendor.haystack.utils.geo import generate_bounding_box
+            from ...haystack.utils.geo import generate_bounding_box
 
             ((south, west), (north, east)) = generate_bounding_box(
                 within["point_1"], within["point_2"]
@@ -619,7 +619,7 @@ class ElasticsearchSearchBackend(BaseSearchBackend):
         result_class=None,
         **kwargs
     ):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         if not self.setup_complete:
             self.setup()
@@ -677,7 +677,7 @@ class ElasticsearchSearchBackend(BaseSearchBackend):
         distance_point=None,
         geo_sort=False,
     ):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         results = []
         hits = self._process_hits(raw_results)
@@ -914,7 +914,7 @@ class ElasticsearchSearchQuery(BaseSearchQuery):
         return "*:*"
 
     def build_query_fragment(self, field, filter_type, value):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         query_frag = ""
 
