@@ -3,21 +3,21 @@ import warnings
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 
-from codex._vendor. import haystack
-from codex._vendor.haystack.backends import (
+from ... import haystack
+from ...haystack.backends import (
     BaseEngine,
     BaseSearchBackend,
     BaseSearchQuery,
     EmptyResults,
     log_query,
 )
-from codex._vendor.haystack.constants import DJANGO_CT, DJANGO_ID, ID
-from codex._vendor.haystack.exceptions import MissingDependency, MoreLikeThisError, SkipDocument
-from codex._vendor.haystack.inputs import Clean, Exact, PythonData, Raw
-from codex._vendor.haystack.models import SearchResult
-from codex._vendor.haystack.utils import get_identifier, get_model_ct
-from codex._vendor.haystack.utils import log as logging
-from codex._vendor.haystack.utils.app_loading import haystack_get_model
+from ...haystack.constants import DJANGO_CT, DJANGO_ID, ID
+from ...haystack.exceptions import MissingDependency, MoreLikeThisError, SkipDocument
+from ...haystack.inputs import Clean, Exact, PythonData, Raw
+from ...haystack.models import SearchResult
+from ...haystack.utils import get_identifier, get_model_ct
+from ...haystack.utils import log as logging
+from ...haystack.utils.app_loading import haystack_get_model
 
 try:
     from pysolr import Solr, SolrError
@@ -66,6 +66,9 @@ class SolrSearchBackend(BaseSearchBackend):
 
         self.collate = connection_options.get("COLLATE_SPELLING", True)
 
+        # Support to `date_facet` on Solr >= 6.6. Olders set `date`
+        self.date_facet_field = connection_options.get("DATE_FACET_FIELD", "range")
+
         self.conn = Solr(
             connection_options["URL"],
             timeout=self.timeout,
@@ -278,23 +281,25 @@ class SolrSearchBackend(BaseSearchBackend):
 
         if date_facets is not None:
             kwargs["facet"] = "on"
-            kwargs["facet.date"] = date_facets.keys()
-            kwargs["facet.date.other"] = "none"
+            kwargs["facet.%s" % self.date_facet_field] = date_facets.keys()
+            kwargs["facet.%s.other" % self.date_facet_field] = "none"
 
             for key, value in date_facets.items():
-                kwargs["f.%s.facet.date.start" % key] = self.conn._from_python(
-                    value.get("start_date")
-                )
-                kwargs["f.%s.facet.date.end" % key] = self.conn._from_python(
-                    value.get("end_date")
-                )
+                kwargs[
+                    "f.%s.facet.%s.start" % (key, self.date_facet_field)
+                ] = self.conn._from_python(value.get("start_date"))
+                kwargs[
+                    "f.%s.facet.%s.end" % (key, self.date_facet_field)
+                ] = self.conn._from_python(value.get("end_date"))
                 gap_by_string = value.get("gap_by").upper()
                 gap_string = "%d%s" % (value.get("gap_amount"), gap_by_string)
 
                 if value.get("gap_amount") != 1:
                     gap_string += "S"
 
-                kwargs["f.%s.facet.date.gap" % key] = "+%s/%s" % (
+                kwargs[
+                    "f.%s.facet.%s.gap" % (key, self.date_facet_field)
+                ] = "+%s/%s" % (
                     gap_string,
                     gap_by_string,
                 )
@@ -338,7 +343,7 @@ class SolrSearchBackend(BaseSearchBackend):
                     kwargs["f.%s.stats.facet" % k] = facet
 
         if within is not None:
-            from codex._vendor.haystack.utils.geo import generate_bounding_box
+            from ...haystack.utils.geo import generate_bounding_box
 
             kwargs.setdefault("fq", [])
             ((min_lat, min_lng), (max_lat, max_lng)) = generate_bounding_box(
@@ -393,7 +398,7 @@ class SolrSearchBackend(BaseSearchBackend):
         result_class=None,
         **kwargs
     ):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         # Deferred models will have a different class ("RealClass_Deferred_fieldname")
         # which won't be in our registry:
@@ -462,7 +467,7 @@ class SolrSearchBackend(BaseSearchBackend):
     def _process_results(
         self, raw_results, highlight=False, result_class=None, distance_point=None
     ):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         results = []
         hits = raw_results.hits
@@ -481,6 +486,7 @@ class SolrSearchBackend(BaseSearchBackend):
                 "fields": raw_results.facets.get("facet_fields", {}),
                 "dates": raw_results.facets.get("facet_dates", {}),
                 "queries": raw_results.facets.get("facet_queries", {}),
+                "ranges": raw_results.facets.get("facet_ranges", {}),
             }
 
             for key in ["fields"]:
@@ -494,6 +500,17 @@ class SolrSearchBackend(BaseSearchBackend):
                         )
                     )
 
+            for key in ["ranges"]:
+                for facet_field in facets[key]:
+                    # Convert to a two-tuple, as Solr's json format returns a list of
+                    # pairs.
+                    facets[key][facet_field] = list(
+                        zip(
+                            facets[key][facet_field]["counts"][::2],
+                            facets[key][facet_field]["counts"][1::2],
+                        )
+                    )
+
         if self.include_spelling and hasattr(raw_results, "spellcheck"):
             try:
                 spelling_suggestions = self.extract_spelling_suggestions(raw_results)
@@ -745,7 +762,7 @@ class SolrSearchQuery(BaseSearchQuery):
         return "*:*"
 
     def build_query_fragment(self, field, filter_type, value):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         query_frag = ""
 
