@@ -7,29 +7,29 @@ import warnings
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.datetime_safe import date, datetime
+from datetime import date, datetime
 from django.utils.encoding import force_str
 
-from codex._vendor.haystack.backends import (
+from ...haystack.backends import (
     BaseEngine,
     BaseSearchBackend,
     BaseSearchQuery,
     EmptyResults,
     log_query,
 )
-from codex._vendor.haystack.constants import (
+from ...haystack.constants import (
     DJANGO_CT,
     DJANGO_ID,
     FUZZY_WHOOSH_MAX_EDITS,
     FUZZY_WHOOSH_MIN_PREFIX,
     ID,
 )
-from codex._vendor.haystack.exceptions import MissingDependency, SearchBackendError, SkipDocument
-from codex._vendor.haystack.inputs import Clean, Exact, PythonData, Raw
-from codex._vendor.haystack.models import SearchResult
-from codex._vendor.haystack.utils import get_identifier, get_model_ct
-from codex._vendor.haystack.utils import log as logging
-from codex._vendor.haystack.utils.app_loading import haystack_get_model
+from ...haystack.exceptions import MissingDependency, SearchBackendError, SkipDocument
+from ...haystack.inputs import Clean, Exact, PythonData, Raw
+from ...haystack.models import SearchResult
+from ...haystack.utils import get_identifier, get_model_ct
+from ...haystack.utils import log as logging
+from ...haystack.utils.app_loading import haystack_get_model
 
 try:
     import whoosh
@@ -124,7 +124,7 @@ class WhooshSearchBackend(BaseSearchBackend):
         """
         Defers loading until needed.
         """
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         new_index = False
 
@@ -711,7 +711,7 @@ class WhooshSearchBackend(BaseSearchBackend):
         result_class=None,
         facet_types=None,
     ):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         results = []
 
@@ -958,7 +958,7 @@ class WhooshSearchQuery(BaseSearchQuery):
         return " ".join(cleaned_words)
 
     def build_query_fragment(self, field, filter_type, value):
-        from codex._vendor.haystack import connections
+        from ...haystack import connections
 
         query_frag = ""
         is_datetime = False
