@@ -5,10 +5,10 @@ import warnings
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.encoding import force_str
 
-from codex._vendor.haystack import connection_router, connections
-from codex._vendor.haystack.constants import Indexable  # NOQA — exposed as a public export
-from codex._vendor.haystack.constants import DEFAULT_ALIAS, DJANGO_CT, DJANGO_ID, ID
-from codex._vendor.haystack.fields import (  # NOQA — exposed as a public export
+from ..haystack import connection_router, connections
+from ..haystack.constants import Indexable  # NOQA — exposed as a public export
+from ..haystack.constants import DEFAULT_ALIAS, DJANGO_CT, DJANGO_ID, ID
+from ..haystack.fields import (  # NOQA — exposed as a public export
     BooleanField,
     CharField,
     DateField,
@@ -27,8 +27,8 @@ from codex._vendor.haystack.fields import (  # NOQA — exposed as a public expo
     SearchField,
     SearchFieldError,
 )
-from codex._vendor.haystack.manager import SearchIndexManager
-from codex._vendor.haystack.utils import get_facet_field_name, get_identifier, get_model_ct
+from ..haystack.manager import SearchIndexManager
+from ..haystack.utils import get_facet_field_name, get_identifier, get_model_ct
 
 
 class DeclarativeMetaclass(type):
