@@ -1,7 +1,7 @@
 from django.core.management.base import BaseCommand
 
-from codex._vendor.haystack import connections
-from codex._vendor.haystack.constants import DEFAULT_ALIAS
+from ....haystack import connections
+from ....haystack.constants import DEFAULT_ALIAS
 
 
 class Command(BaseCommand):
