@@ -2,12 +2,12 @@ import operator
 import warnings
 from functools import reduce
 
-from codex._vendor.haystack import connection_router, connections
-from codex._vendor.haystack.backends import SQ
-from codex._vendor.haystack.constants import DEFAULT_OPERATOR, ITERATOR_LOAD_PER_QUERY
-from codex._vendor.haystack.exceptions import NotHandled
-from codex._vendor.haystack.inputs import AutoQuery, Raw
-from codex._vendor.haystack.utils import log as logging
+from ..haystack import connection_router, connections
+from ..haystack.backends import SQ
+from ..haystack.constants import DEFAULT_OPERATOR, ITERATOR_LOAD_PER_QUERY
+from ..haystack.exceptions import NotHandled
+from ..haystack.inputs import AutoQuery, Raw
+from ..haystack.utils import log as logging
 
 
 class SearchQuerySet:
