@@ -1,4 +1,4 @@
-from codex._vendor.haystack.constants import DEFAULT_ALIAS
+from ..haystack.constants import DEFAULT_ALIAS
 
 
 class BaseRouter:
