@@ -1,5 +1,5 @@
 from django.urls import path
 
-from codex._vendor.haystack.views import SearchView
+from ..haystack.views import SearchView
 
 urlpatterns = [path("", SearchView(), name="haystack_search")]
