@@ -1,14 +1,15 @@
-"""DB Updater Tasks."""
+"""DB Import Tasks."""
+
 from dataclasses import dataclass
 
 
 @dataclass
-class UpdaterTask:
+class ImportTask:
     """Tasks for the updater."""
 
 
 @dataclass
-class UpdaterDBDiffTask(UpdaterTask):
+class ImportDBDiffTask(ImportTask):
     """For sending to the updater."""
 
     library_id: int
@@ -20,8 +21,16 @@ class UpdaterDBDiffTask(UpdaterTask):
     files_created: frozenset[str]
     dirs_deleted: frozenset[str]
     files_deleted: frozenset[str]
+    force_import_metadata: bool = False
 
 
 @dataclass
-class AdoptOrphanFoldersTask(UpdaterTask):
+class LazyImportComicsTask(ImportTask):
+    """Lazy import of metadaa for existing comics."""
+
+    pks: frozenset[int]
+
+
+@dataclass
+class AdoptOrphanFoldersTask(ImportTask):
     """Move orphaned folders into a correct tree position."""
