@@ -1,6 +1,8 @@
 """Haystack Search index updater."""
+
 from codex.librarian.search.merge import MergeMixin
 from codex.librarian.search.tasks import (
+    SearchIndexClearTask,
     SearchIndexMergeTask,
     SearchIndexRebuildIfDBChangedTask,
     SearchIndexRemoveStaleTask,
@@ -12,8 +14,9 @@ from codex.librarian.search.update import UpdateMixin
 class SearchIndexerThread(UpdateMixin, MergeMixin):
     """A worker to handle search index update tasks."""
 
-    def process_item(self, task):
+    def process_item(self, item):
         """Run the updater."""
+        task = item
         if isinstance(task, SearchIndexRebuildIfDBChangedTask):
             self.rebuild_search_index_if_db_changed()
         elif isinstance(task, SearchIndexUpdateTask):
@@ -22,5 +25,7 @@ class SearchIndexerThread(UpdateMixin, MergeMixin):
             self.merge_search_index(task.optimize)
         elif isinstance(task, SearchIndexRemoveStaleTask):
             self.remove_stale_records()
+        elif isinstance(task, SearchIndexClearTask):
+            self.clear_search_index()
         else:
             self.log.warning(f"Bad task sent to search index thread: {task}")
