@@ -1,4 +1,5 @@
 """Librarian Tasks."""
+
 from dataclasses import dataclass, field
 
 
@@ -8,3 +9,7 @@ class DelayedTasks:
 
     until: float
     tasks: tuple = field(compare=False)
+
+
+class LibrarianShutdownTask:
+    """Empty task."""
