@@ -1,22 +1,22 @@
 """Custom Haystack Search Backend."""
+
 from math import ceil
 from multiprocessing import cpu_count
 from pathlib import Path
 from types import MappingProxyType
 
 from django.utils.timezone import now
-from haystack.backends.whoosh_backend import (
-    WHOOSH_ID,
-    WhooshSearchBackend,
-)
-from haystack.constants import DJANGO_CT, DJANGO_ID, ID
-from haystack.exceptions import SearchBackendError, SkipDocument
 from humanfriendly import InvalidSize, parse_size
-from whoosh.analysis import CharsetFilter, StandardAnalyzer, StemFilter
+from whoosh.analysis import (
+    CharsetFilter,
+    StemFilter,
+    StemmingAnalyzer,
+)
 from whoosh.fields import BOOLEAN, DATETIME, NUMERIC, TEXT, FieldType, Schema
 from whoosh.filedb.filestore import FileStorage
 from whoosh.index import EmptyIndexError
 from whoosh.qparser import (
+    CopyFieldPlugin,
     FieldAliasPlugin,
     GtLtPlugin,
     OperatorsPlugin,
@@ -26,10 +26,16 @@ from whoosh.qparser.dateparse import DateParserPlugin
 from whoosh.query import Or, Term
 from whoosh.support.charset import accent_map
 
+from codex._vendor.haystack.backends.whoosh_backend import (
+    WHOOSH_ID,
+    WhooshSearchBackend,
+)
+from codex._vendor.haystack.constants import DJANGO_CT, DJANGO_ID, ID
+from codex._vendor.haystack.exceptions import SearchBackendError, SkipDocument
 from codex.librarian.search.status import SearchIndexStatusTypes
 from codex.logger.logging import get_logger
 from codex.memory import get_mem_limit
-from codex.models import Comic
+from codex.models import AdminFlag, Comic
 from codex.search.indexes import ComicIndex
 from codex.search.writing import CodexWriter
 from codex.settings.settings import (
@@ -55,7 +61,8 @@ def gen_multipart_field_aliases(field):
     for connector in ("", "-"):
         joined = connector.join(bits)
         aliases += [joined, joined[:-1]]
-    return aliases
+
+    return tuple(sorted(frozenset(aliases)))
 
 
 class FILESIZE(NUMERIC):
@@ -91,7 +98,8 @@ class FILESIZE(NUMERIC):
 
 
 TEXT_ANALYZER = (
-    StandardAnalyzer() | CharsetFilter(accent_map) | StemFilter(cachesize=-1)
+    # StandardAnalyzer() | CharsetFilter(accent_map) | StemFilter(cachesize=-1)
+    StemmingAnalyzer(minsize=1) | CharsetFilter(accent_map) | StemFilter(cachesize=-1)
 )
 
 
@@ -100,37 +108,44 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
 
     FIELDMAP = MappingProxyType(
         {
-            "characters": ["category", "character"],
-            "created_at": ["created"],
-            "creators": [
-                "author",
-                "authors",
-                "contributor",
-                "contributors",
-                "creator",
-                "creator",
-                "creators",
-            ],
+            "characters": ("category", "character"),
             "community_rating": gen_multipart_field_aliases("community_rating"),
+            "contributors": (
+                *gen_multipart_field_aliases("authors"),
+                "contributor",
+                *gen_multipart_field_aliases("creators"),
+                *gen_multipart_field_aliases("credits"),
+                *gen_multipart_field_aliases("people"),
+                *gen_multipart_field_aliases("persons"),
+            ),
+            "created_at": ("created",),
             "critical_rating": gen_multipart_field_aliases("critical_rating"),
-            "genres": ["genre"],
-            "file_type": ["type"],
-            "locations": ["location"],
-            "name": ["title"],
-            "original_format": ["format"],
-            "page_count": ["pages"],
-            "read_ltr": ["ltr"],
+            "genres": ("genre",),
+            "file_type": ("type",),
+            "identifier": ("id", "nss"),
+            "identifier_type": ("idtype", "id_type", "nid"),
+            "issue_number": ("number",),
+            "locations": ("location",),
+            "monochrome": gen_multipart_field_aliases("black_and_white"),
+            "name": ("title",),
+            "original_format": ("format",),
+            "page_count": ("pages",),
+            "reading_direction": ("direction",),
+            "search_path": ("path", *gen_multipart_field_aliases("folders")),
             "series_groups": gen_multipart_field_aliases("series_groups"),
-            "scan_info": ["scan"],
+            "scan_info": ("scan",),
+            "stories": ("story",),
             "story_arcs": gen_multipart_field_aliases("story_arcs"),
-            "tags": ["tag"],
-            "teams": ["team"],
-            "updated_at": ["updated"],
+            "summary": ("comments", "description"),
+            "tags": ("tag",),
+            "teams": ("team",),
+            "updated_at": ("updated",),
         }
     )
     RESERVED_CHARACTERS = ()
     RESERVED_WORDS = ()
     FIELD_ALIAS_PLUGIN = FieldAliasPlugin(FIELDMAP)
+    COPY_FIELD_PLUGIN = CopyFieldPlugin({"issue_number": "issue_suffix"})
     OPERATORS_PLUGIN = OperatorsPlugin(
         ops=None,
         clean=False,
@@ -154,14 +169,14 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
     _SELECT_RELATED_FIELDS = ("publisher", "imprint", "series", "volume")
     _PREFETCH_RELATED_FIELDS = (
         "characters",
-        "creators",
+        "contributors",
         "genres",
         "locations",
         "series_groups",
         "story_arc_numbers__story_arc",
         "tags",
         "teams",
-        "creators__person",
+        "contributors__person",
     )
     _DEFERRED_FIELDS = (
         "parent_folder",
@@ -169,7 +184,6 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
         "path",
         "stat",
         # "folders", # don't explicitly defer m2m
-        "max_page",
     )
     _ONEMB = 1024**2
     ###################
@@ -182,6 +196,8 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
     _CPU_MULTIPLIER = CPU_MULTIPLIER
     _CHUNK_PER_GB = CHUNK_PER_GB
     _MAX_CHUNK_SIZE = MAX_CHUNK_SIZE
+    _DECIMAL_FIELD_NAMES = frozenset({"decimal", "float"})
+    _DATETIME_FIELD_NAMES = frozenset({"date", "datetime"})
 
     def __init__(self, connection_alias, **connection_options):
         """Init worker queues."""
@@ -204,10 +220,6 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
             int(mem_limit_gb * self._CHUNK_PER_GB), self._MAX_CHUNK_SIZE
         )
 
-    @staticmethod
-    def _get_text_analyzer():
-        return StandardAnalyzer() | CharsetFilter(accent_map) | StemFilter(cachesize=-1)
-
     def build_schema(self, fields):
         """Customize Codex Schema.
 
@@ -236,20 +248,15 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
                     signed=False,
                     stored=field_class.stored,
                 )
-            elif field_class.field_type == "float":
-                # my only floats are small decimals.
+            elif field_class.field_type in self._DECIMAL_FIELD_NAMES:
                 schema_fields[index_fieldname] = NUMERIC(
-                    numtype=int,  # Decimal is converted to int in NUMERIC
-                    bits=64,
+                    numtype=float,  # type: ignore
                     field_boost=field_class.boost,
-                    signed=False,
-                    decimal_places=2,
                     stored=field_class.stored,
                 )
-            elif field_class.field_type in ["date", "datetime"]:
+            elif field_class.field_type in self._DATETIME_FIELD_NAMES:
                 schema_fields[index_fieldname] = DATETIME(
                     stored=field_class.stored,
-                    # sortable=True  # index_fieldname == "updated_at"
                 )
             elif field_class.field_type == "boolean":
                 # Field boost isn't supported on BOOLEAN as of 1.8.2.
@@ -258,9 +265,7 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
                 schema_fields[index_fieldname] = TEXT(
                     stored=True,
                     analyzer=TEXT_ANALYZER,
-                    # analyzer=field_class.analyzer  or StemmingAnalyzer(),
                     field_boost=field_class.boost,
-                    # sortable=True,
                     spelling=field_class.document is True,
                 )
                 if field_class.document:
@@ -278,7 +283,7 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
         return (content_field_name, Schema(**schema_fields))
 
     def _setup_storage_patch(self):
-        """Adapt FileStorage to not use mmap in low memory environements."""
+        """Adapt FileStorage to not use mmap in low memory environments."""
         if not self.use_file_storage:
             return
 
@@ -312,7 +317,12 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
         # https://github.com/mchaput/whoosh/pull/11
         self.parser.remove_plugin_class(WhitespacePlugin)
         self.parser.replace_plugin(self.OPERATORS_PLUGIN)
-        plugins = [WhitespacePlugin, self.FIELD_ALIAS_PLUGIN, GtLtPlugin]
+        plugins = [
+            WhitespacePlugin,
+            self.COPY_FIELD_PLUGIN,
+            self.FIELD_ALIAS_PLUGIN,
+            GtLtPlugin,
+        ]
         plugins += [DateParserPlugin(basedate=now())]
         self.parser.add_plugins(plugins)
 
@@ -421,8 +431,16 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
             raise
         return count
 
-    def update(self, index, batch_pks, batch_num=0, abort_event=None, **kwargs):
+    def update(  # noqa: PLR0913, # type: ignore
+        self,
+        index,
+        iterable,
+        commit=True,  # noqa: ARG002
+        batch_num=0,
+        abort_event=None,
+    ):
         """Update index, but with writer options."""
+        batch_pks = iterable
         count = 0
         if abort_event and abort_event.is_set():
             self.log.debug(
@@ -443,12 +461,19 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
             )
             return count
 
+        folder_view_enabled = AdminFlag.objects.get(
+            key=AdminFlag.FlagChoices.FOLDER_VIEW.value
+        ).on
         for obj in iterable:
             if abort_event and abort_event.is_set():
                 self.log.debug(
                     f"Stopped search index update batch {batch_num} at {count} updates."
                 )
                 break
+            if not folder_view_enabled:
+                # Hide path if folder view is disabled.
+                # This also affects field search.
+                obj.search_path = ""  # type: ignore
             count += self._update_obj(index, writer, batch_num, obj)
         return self._update_finish(count, batch_num, writer)
 
@@ -477,7 +502,12 @@ class CodexSearchBackend(WhooshSearchBackend, WorkerBaseMixin):
         """Optimize the index."""
         if not self.setup_complete:
             self.setup(False)
-        self.index.refresh().optimize(**self.writerargs)
+        try:
+            self.index.refresh().optimize(**self.writerargs)
+        except Exception as exc:
+            self.log.warn(
+                f"Search Index unable to optimize '{exc}', it may work next time."
+            )
 
     def merge_small(self):
         """Merge small segments of the index."""
