@@ -4,6 +4,7 @@ Extract the same json the frontend uses for the values so they're always
 in sync.
 Which is a little bit of overengineering.
 """
+
 import json
 import mmap
 import re
@@ -47,7 +48,7 @@ _CHOICES_FN_RE = {
     _CHOICES_MODULE_NAME: create_choices_fn_regexes(_CHOICES_MODULE_NAME),
     _ADMIN_CHOICES_MODULE_NAME: create_choices_fn_regexes(_ADMIN_CHOICES_MODULE_NAME),
 }
-
+_SINGLE_VALUE_KEYS = frozenset({"q", "route"})
 
 # Exports
 CHOICES = {}
@@ -76,16 +77,20 @@ def _parse_choices(module_name):
         try:
             path = _find_filename_regex(js_root, module_name)
             if not path:
+                LOG.warning(f"Could not find json choices at {path}")
                 continue
-            with path.open("r") as choices_file, mmap.mmap(
-                choices_file.fileno(), 0, access=mmap.ACCESS_READ
-            ) as choices_mmap_file:
+            with (
+                path.open("r") as choices_file,
+                mmap.mmap(
+                    choices_file.fileno(), 0, access=mmap.ACCESS_READ
+                ) as choices_mmap_file,
+            ):
                 json_str = choices_mmap_file.read()
                 data_dict = json.loads(json_str)
                 LOG.debug(f"Loaded json choices from {js_root} {module_name}")
                 break
-        except Exception as exc:
-            LOG.exception(exc)
+        except Exception:
+            LOG.exception(f"Reading {js_root}")
     if not data_dict:
         LOG.error(f"Could not extract values from {module_name}")
 
@@ -116,18 +121,20 @@ def _parse_choices_to_dict(vuetify_key, vuetify_list):
 def _build_choices_and_defaults(data_dict):
     """Transform the vuetify choice formatted data to key:value dicts."""
     global VUETIFY_NULL_CODE  # noqa PLW0603
-    for vuetify_key, vuetify_list in data_dict.items():
+    for vuetify_key, value in data_dict.items():
+        if vuetify_key in ("identifierTypes", "groupNames"):
+            continue
+        if vuetify_key in _SINGLE_VALUE_KEYS:
+            DEFAULTS[vuetify_key] = value
+            continue
         if vuetify_key == "settingsGroup":
-            DEFAULTS["show"] = _build_show_defaults(vuetify_list)
+            DEFAULTS["show"] = _build_show_defaults(value)
             continue
         if vuetify_key == "vuetifyNullCode":
-            VUETIFY_NULL_CODE = vuetify_list
-            continue
-        if vuetify_key in ("q", "route"):
-            DEFAULTS[vuetify_key] = vuetify_list
+            VUETIFY_NULL_CODE = value
             continue
 
-        CHOICES[vuetify_key] = _parse_choices_to_dict(vuetify_key, vuetify_list)
+        CHOICES[vuetify_key] = _parse_choices_to_dict(vuetify_key, value)
 
 
 def _load_choices_json():
@@ -141,8 +148,6 @@ def _load_choices_json():
         if key == "websockets":
             WEBSOCKET_MESSAGES = value
         else:
-            if key == "browser":
-                del value["groupNames"]
             _build_choices_and_defaults(value)
         LOG.debug(f"Parsed {key} choices")
 
