@@ -1,16 +1,16 @@
 """Librarian Status dataclass."""
+
 from dataclasses import dataclass
 from enum import Enum
-from typing import Optional, Union
 
 
 @dataclass
 class Status:
     """Args for passing into import functions."""
 
-    status_type: Union[str, Enum]
-    complete: Optional[int] = None
-    total: Optional[int] = None
+    status_type: str | Enum
+    complete: int | None = None
+    total: int | None = None
     since: float = 0.0
     subtitle: str = ""
 
@@ -19,11 +19,15 @@ class Status:
         if isinstance(self.status_type, Enum):
             self.status_type = self.status_type.value
 
-    def increment_complete(self):
-        """Increment complete handling None."""
+    def add_complete(self, count: int):
+        """Add count to complete."""
         if self.complete is None:
             self.complete = 0
-        self.complete += 1
+        self.complete += count
+
+    def increment_complete(self):
+        """Increment complete handling None."""
+        self.add_complete(1)
 
     def decrement_total(self):
         """Decreent total if not not."""
