@@ -1,24 +1,24 @@
-{% load static %}
-var CACHE_PREFIX = "codex-pwa-v"
-var STATIC_CACHE_NAME = CACHE_PREFIX + new Date().getTime();
+// {% load static %}
+var CACHE_PREFIX = "codex-pwa-v";
+var STATIC_CACHE_NAME = CACHE_PREFIX + new Date().getSeconds();
 var OFFLINE_PATH = "{% static 'pwa/offline.html' %}";
 var FILES_TO_CACHE = [
   OFFLINE_PATH,
-  "{% static 'img/logo-maskable-180.webp' %}",
-  "{% static 'img/logo.svg' %}",
   "{% static 'img/logo-32.webp' %}",
+  "{% static 'img/logo-maskable-180.webp' %}",
   "{% static 'img/logo-maskable.svg' %}",
+  "{% static 'img/logo.svg' %}",
 ];
-// Cache on install
+// Cache offline page on install
 self.addEventListener("install", (event) => {
   this.skipWaiting();
   event.waitUntil(
     caches.open(STATIC_CACHE_NAME).then((cache) => {
       return cache.addAll(FILES_TO_CACHE);
-    })
+    }),
   );
 });
-// Clear cache on activate
+// Clear old caches on activate
 self.addEventListener("activate", (event) => {
   event.waitUntil(
     caches.keys().then((cacheNames) => {
@@ -26,9 +26,9 @@ self.addEventListener("activate", (event) => {
         cacheNames
           .filter((cacheName) => cacheName.startsWith(CACHE_PREFIX))
           .filter((cacheName) => cacheName !== STATIC_CACHE_NAME)
-          .map((cacheName) => caches.delete(cacheName))
+          .map((cacheName) => caches.delete(cacheName)),
       );
-    })
+    }),
   );
 });
 // Serve from Cache
@@ -41,6 +41,6 @@ self.addEventListener("fetch", (event) => {
       })
       .catch(() => {
         return caches.match(OFFLINE_PATH);
-      })
+      }),
   );
 });
