@@ -2,16 +2,20 @@
 
 https://docs.djangoproject.com/en/dev/topics/http/urls/
 """
+
 from django.contrib.staticfiles.storage import staticfiles_storage
-from django.urls import include, path, register_converter
+from django.urls import include, path, register_converter, set_script_prefix
 from django.views.generic.base import RedirectView
 
+from codex.settings.settings import ROOT_PATH
 from codex.urls.converters import GroupConverter
 
-TIMEOUT = 60 * 60
-
 register_converter(GroupConverter, "group")
 
+if ROOT_PATH:
+    # Django 5 bug https://code.djangoproject.com/ticket/35169#comment:11
+    set_script_prefix(ROOT_PATH)
+
 urlpatterns = [
     path(
         "favicon.ico",
