@@ -1,4 +1,5 @@
 """Admin Flag View."""
+
 from typing import ClassVar
 
 from rest_framework.permissions import IsAdminUser
@@ -17,7 +18,7 @@ LOG = get_logger(__name__)
 class AdminFlagViewSet(ModelViewSet):
     """Admin Flag Viewset."""
 
-    permission_classes: ClassVar[list] = [IsAdminUser]
+    permission_classes: ClassVar[list] = [IsAdminUser]  # type: ignore
     queryset = AdminFlag.objects.all()
     serializer_class = AdminFlagSerializer
     lookup_field = "key"
