@@ -1,4 +1,5 @@
 """Group View."""
+
 from typing import ClassVar
 
 from django.contrib.auth.models import Group
@@ -17,15 +18,19 @@ LOG = get_logger(__name__)
 class AdminGroupViewSet(ModelViewSet):
     """Admin Group Viewset."""
 
-    permission_classes: ClassVar[list] = [IsAdminUser]
-    queryset = Group.objects.prefetch_related("user_set", "library_set")
+    permission_classes: ClassVar[list] = [IsAdminUser]  # type: ignore
+    queryset = Group.objects.prefetch_related("user_set", "library_set").select_related(
+        "groupauth"
+    )
     serializer_class = GroupSerializer
 
-    CHANGE_FIELDS = frozenset(("librarySet", "userSet"))
+    _CHANGE_FIELDS = frozenset({"librarySet", "userSet", "groupauth"})
 
-    def _on_change(self, validated_keys):
+    def _on_change(self, validated_data=None):
         """On change hook."""
-        if validated_keys.intersection(self.CHANGE_FIELDS):
+        if not validated_data or frozenset(validated_data.keys()).intersection(
+            self._CHANGE_FIELDS
+        ):
             cache.clear()
             LIBRARIAN_QUEUE.put(LIBRARY_CHANGED_TASK)
 
@@ -36,17 +41,17 @@ class AdminGroupViewSet(ModelViewSet):
 
     def perform_update(self, serializer):
         """Perform update and run hooks."""
-        validated_keys = frozenset(serializer.validated_data.keys())
+        validated_data = serializer.validated_data
         super().perform_update(serializer)
-        self._on_change(validated_keys)
+        self._on_change(validated_data)
 
     def perform_create(self, serializer):
         """Perform create and run hooks."""
-        validated_keys = frozenset(serializer.validated_data.keys())
+        validated_data = serializer.validated_data
         super().perform_create(serializer)
-        self._on_change(validated_keys)
+        self._on_change(validated_data)
 
     def perform_destroy(self, instance):
         """Perform destroy and run hooks."""
         super().perform_destroy(instance)
-        self._on_change(self.CHANGE_FIELDS)
+        self._on_change()
