@@ -1,9 +1,11 @@
 """Admin Library Views."""
+
 from pathlib import Path
 from time import time
 from typing import ClassVar
 
 from django.core.cache import cache
+from drf_spectacular.utils import extend_schema
 from rest_framework.exceptions import ValidationError
 from rest_framework.generics import GenericAPIView
 from rest_framework.permissions import IsAdminUser
@@ -29,13 +31,13 @@ LOG = get_logger(__name__)
 class AdminLibraryViewSet(ModelViewSet):
     """Admin Library Viewset."""
 
-    permission_classes: ClassVar[list] = [IsAdminUser]
+    permission_classes: ClassVar[list] = [IsAdminUser]  # type: ignore
     queryset = Library.objects.prefetch_related("groups").defer(
         "update_in_progress", "created_at", "updated_at"
     )
     serializer_class = LibrarySerializer
 
-    WATCHDOG_SYNC_FIELDS = frozenset(("events", "poll", "pollEvery"))
+    WATCHDOG_SYNC_FIELDS = frozenset({"events", "poll", "pollEvery"})
 
     def _create_library_folder(self, library):
         folder = Folder(
@@ -56,7 +58,7 @@ class AdminLibraryViewSet(ModelViewSet):
 
     @staticmethod
     def _poll(pk, force):
-        task = WatchdogPollLibrariesTask(frozenset((pk,)), force)
+        task = WatchdogPollLibrariesTask(frozenset({pk}), force)
         LIBRARIAN_QUEUE.put(task)
 
     def perform_update(self, serializer):
@@ -90,7 +92,7 @@ class AdminLibraryViewSet(ModelViewSet):
 class AdminFailedImportViewSet(ModelViewSet):
     """Admin FailedImport Viewset."""
 
-    permission_classes: ClassVar[list] = [IsAdminUser]
+    permission_classes: ClassVar[list] = [IsAdminUser]  # type: ignore
     queryset = FailedImport.objects.defer("updated_at")
     serializer_class = FailedImportSerializer
 
@@ -98,11 +100,12 @@ class AdminFailedImportViewSet(ModelViewSet):
 class AdminFolderListView(GenericAPIView):
     """List server directories."""
 
-    permission_classes: ClassVar[list] = [IsAdminUser]
+    permission_classes: ClassVar[list] = [IsAdminUser]  # type:ignore
     serializer_class = AdminFolderListSerializer
     input_serializer_class = AdminFolderSerializer
 
-    def get(self, *args, **kwargs):
+    @extend_schema(request=input_serializer_class)
+    def get(self, *_args, **_kwargs):
         """Get subdirectories for a path."""
         try:
             serializer = self.input_serializer_class(data=self.request.query_params)
@@ -127,7 +130,7 @@ class AdminFolderListView(GenericAPIView):
         except ValidationError:
             raise
         except Exception as exc:
-            LOG.exception(exc)
+            LOG.exception("get admin folder list view")
             reason = "Server Error"
             raise ValidationError(reason) from exc
         else:
