@@ -1,10 +1,12 @@
 """Views for browsing comic library."""
+
 import json
 from copy import deepcopy
 from types import MappingProxyType
 from urllib.parse import unquote_plus
 
 from django.contrib.auth.models import User
+from django.db.models import Q
 from djangorestframework_camel_case.settings import api_settings
 from djangorestframework_camel_case.util import underscoreize
 
@@ -18,7 +20,7 @@ from codex.models import (
     StoryArc,
     Volume,
 )
-from codex.serializers.browser import BrowserSettingsSerializer
+from codex.serializers.browser.settings import BrowserSettingsSerializer
 from codex.views.browser.filters.bookmark import BookmarkFilterMixin
 from codex.views.browser.filters.field import ComicFieldFilter
 from codex.views.browser.filters.group import GroupFilterMixin
@@ -47,7 +49,7 @@ class BrowserBaseView(
         }
     )
 
-    _GET_JSON_KEYS = frozenset(("filters", "show"))
+    _GET_JSON_KEYS = frozenset({"filters", "show"})
 
     def __init__(self, *args, **kwargs):
         """Set params for the type checker."""
@@ -67,11 +69,13 @@ class BrowserBaseView(
         object_filter = self.get_group_acl_filter(model)
         object_filter &= self.get_search_filter(model, search_scores)
         object_filter &= self.get_bookmark_filter(model)
-        object_filter &= self.get_comic_field_filter()
+        object_filter &= self.get_comic_field_filter(self.rel_prefix)
         return object_filter
 
-    def get_query_filters(self, model, search_scores: dict, choices=False):
+    def get_query_filters(self, model, search_scores: dict | None, choices=False):
         """Return the main object filter and the one for aggregates."""
+        if search_scores is None:
+            return Q(False)
         object_filter = self.get_query_filters_without_group(model, search_scores)
         object_filter &= self.get_group_filter(choices)
         return object_filter
@@ -85,10 +89,21 @@ class BrowserBaseView(
                 parsed_val = json.loads(unquoted_val)
                 if not parsed_val:
                     continue
+                parsed_key = key
+            elif key in ("q", "query"):
+                # parse and strip query param
+                # "query" is used by opds v2
+                if "q" in result:
+                    continue
+                parsed_val = val.strip()
+                if not parsed_val:
+                    continue
+                parsed_key = "q"
             else:
+                parsed_key = key
                 parsed_val = val
 
-            result[key] = parsed_val
+            result[parsed_key] = parsed_val
         return underscoreize(result, **api_settings.JSON_UNDERSCOREIZE)
 
     def parse_params(self):
