@@ -1,7 +1,9 @@
 """Views for browsing comic library."""
+
 from copy import deepcopy
+from math import ceil
 from types import MappingProxyType
-from typing import ClassVar, Optional
+from typing import ClassVar
 
 from django.core.paginator import EmptyPage, Paginator
 from django.db.models import F, Max, Value
@@ -26,26 +28,28 @@ from codex.models import (
     Timestamp,
     Volume,
 )
-from codex.serializers.browser import BrowserPageSerializer
-from codex.serializers.choices import CHOICES, DEFAULTS
+from codex.serializers.browser.page import BrowserPageSerializer
+from codex.serializers.choices import DEFAULTS
 from codex.views.auth import IsAuthenticatedOrEnabledNonUsers
 from codex.views.browser.browser_annotations import BrowserAnnotationsView
+from codex.views.browser.const import MAX_OBJ_PER_PAGE
 
 LOG = get_logger(__name__)
+_ADMIN_FLAG_VALUE_KEY_MAP = MappingProxyType(
+    {
+        AdminFlag.FlagChoices.FOLDER_VIEW.value: "folder_view",
+        AdminFlag.FlagChoices.IMPORT_METADATA.value: "import_metadata",
+    }
+)
 
 
 class BrowserView(BrowserAnnotationsView):
     """Browse comics with a variety of filters and sorts."""
 
-    permission_classes: ClassVar[list] = [IsAuthenticatedOrEnabledNonUsers]
+    permission_classes: ClassVar[list] = [IsAuthenticatedOrEnabledNonUsers]  # type: ignore
     serializer_class = BrowserPageSerializer
 
-    MAX_OBJ_PER_PAGE = 100
-    _MODEL_GROUP_MAP = MappingProxyType(
-        {v: k for k, v in BrowserAnnotationsView.GROUP_MODEL_MAP.items()}
-    )
     _NAV_GROUPS = "rpisv"
-    _ORPHANS = int(MAX_OBJ_PER_PAGE / 20)
 
     _GROUP_INSTANCE_SELECT_RELATED = MappingProxyType(
         {
@@ -58,10 +62,9 @@ class BrowserView(BrowserAnnotationsView):
             StoryArc: (None,),
         }
     )
-    DEFAULT_ROUTE_NAME = "browser"
-    _DEFAULT_ROUTE = MappingProxyType(
+    DEFAULT_ROUTE = MappingProxyType(
         {
-            "name": DEFAULT_ROUTE_NAME,
+            "name": "browser",
             "params": deepcopy(DEFAULTS["route"]),
         }
     )
@@ -74,15 +77,15 @@ class BrowserView(BrowserAnnotationsView):
         "story_arc_numbers__story_arc",
         "tags",
         "teams",
-        "creators",
-        "creators__role",
-        "creators__person",
+        "contributors",
+        "contributors__role",
+        "contributors__person",
     )
 
     is_opds_2_acquisition = False
 
     def _annotate_group_names(self, queryset, model):
-        """Annotate name fields."""
+        """Annotate name fields by hoisting them up."""
         # Optimized to only lookup what is used on the frontend
         group_names = {}
         if model == Comic:
@@ -99,16 +102,15 @@ class BrowserView(BrowserAnnotationsView):
             group_names["publisher_name"] = F("publisher__name")
         return queryset.annotate(**group_names)
 
+    def _annotate_group(self, queryset, model):
+        """Annotate Group."""
+        value = "c" if model == Comic else self.model_group
+        return queryset.annotate(group=Value(value, CharField(max_length=1)))
+
     def _add_annotations(self, queryset, model, search_scores: dict):
         """Annotations for display and sorting."""
         queryset = self.annotate_common_aggregates(queryset, model, search_scores)
-
-        # Annotate Group
-        self.model_group = self._MODEL_GROUP_MAP[model]
-        queryset = queryset.annotate(
-            group=Value(self.model_group, CharField(max_length=1))
-        )
-        # Hoist Group Names
+        queryset = self._annotate_group(queryset, model)
         return self._annotate_group_names(queryset, model)
 
     def _get_model_group(self):
@@ -132,32 +134,35 @@ class BrowserView(BrowserAnnotationsView):
         group = self.kwargs["group"]
         self.group_class = self.GROUP_MODEL_MAP[group]
 
-        model_group = self._get_model_group()
-        self.model = self.GROUP_MODEL_MAP[model_group]
+        self.model_group = self._get_model_group()
+        self.model = self.GROUP_MODEL_MAP[self.model_group]
 
-    def _get_group_queryset(self, search_scores: dict):
-        """Create group queryset."""
-        if not self.model:
-            reason = "Model not set in browser."
-            raise ValueError(reason)
-        if self.model != Comic:
-            object_filter = self.get_query_filters(self.model, search_scores, False)
-            qs = self.model.objects.filter(object_filter)
-            qs = self._add_annotations(qs, self.model, search_scores)
-            qs = self.add_order_by(qs, self.model)
-        else:
-            qs = self.model.objects.none()
+    def _get_common_queryset(self, model, search_scores):
+        """Create queryset common to group & books."""
+        object_filter = self.get_query_filters(model, search_scores, False)
+        qs = model.objects.filter(object_filter)
+        qs = self._add_annotations(qs, model, search_scores)
+        qs = self.add_order_by(qs, model)
+        if limit := self.params.get("limit"):
+            # limit only is set by some opds views
+            qs = qs[:limit]
         return qs
 
-    def _get_book_queryset(self, search_scores: dict):
+    def _get_group_queryset(self, search_scores: dict | None):
+        """Create group queryset."""
+        if not self.model:
+            reason = "Model not set for browser queryset."
+            raise ValueError(reason)
+        if self.model == Comic or search_scores is None:
+            qs = self.model.objects.none()
+        else:
+            qs = self._get_common_queryset(self.model, search_scores)
+        return qs
+
+    def _get_book_queryset(self, search_scores: dict | None):
         """Create book queryset."""
-        if self.model in (Comic, Folder):
-            object_filter = self.get_query_filters(Comic, search_scores, False)
-            qs = Comic.objects.filter(object_filter)
-            qs = self._add_annotations(qs, Comic, search_scores)
-            qs = self.add_order_by(qs, Comic)
-            if limit := self.params.get("limit"):
-                qs = qs[:limit]
+        if self.model in (Comic, Folder) and search_scores is not None:
+            qs = self._get_common_queryset(Comic, search_scores)
         else:
             qs = Comic.objects.none()
         return qs
@@ -191,15 +196,19 @@ class BrowserView(BrowserAnnotationsView):
                 select_related: tuple[str, ...] = self._GROUP_INSTANCE_SELECT_RELATED[
                     self.group_class
                 ]  # type: ignore
-                self.group_instance: Optional[
-                    BrowserGroupModel
-                ] = self.group_class.objects.select_related(*select_related).get(pk=pk)
+                self.group_instance: BrowserGroupModel | None = (
+                    self.group_class.objects.select_related(*select_related).get(pk=pk)
+                )
             except self.group_class.DoesNotExist:
                 group = self.kwargs.get("group")
-                reason = f"{group}={pk} does not exist!"
-                self._raise_redirect({"group": group, "pk": 0, "page": 1}, reason)
+                page = self.kwargs.get("page")
+                if group == "r" and pk == 0 and page == 1:
+                    self.group_instance: BrowserGroupModel | None = None
+                else:
+                    reason = f"{group}={pk} does not exist!"
+                    self._raise_redirect({"group": group, "pk": 0, "page": 1}, reason)
         else:
-            self.group_instance: Optional[BrowserGroupModel] = None
+            self.group_instance: BrowserGroupModel | None = None
 
     def _get_browse_up_route(self):
         """Get the up route from the first valid ancestor."""
@@ -279,53 +288,98 @@ class BrowserView(BrowserAnnotationsView):
             "group_count": group_count,
         }
 
-    def _page_out_out_bounds(self, page, num_pages):
+    def _page_out_of_bounds(self, num_pages):
         """Redirect page out of bounds."""
         group = self.kwargs.get("group")
-        pk = self.kwargs.get("pk", 1)
-        new_page = num_pages if page > num_pages else 1
+        pk = self.kwargs.get("pk", 0)
+        page = self.kwargs.get("page", 1)
+        if group == "r" and pk == 0 and page == 1:
+            # Don't redirect if on the root page.
+            return
+
+        if num_pages:
+            new_page = num_pages if page > num_pages else 1
+        else:
+            # Redirect to root.
+            group = "r"
+            pk = 0
+            new_page = 1
         route_changes = {"group": group, "pk": pk, "page": new_page}
         reason = f"{page=} does not exist!"
         LOG.debug(f"{reason} redirect to page {new_page}.")
         self._raise_redirect(route_changes, reason)
 
-    def _paginate_section(self, qs, max_obj_per_page, page_counts):
+    def _paginate_section(self, model, qs, page):
         """Paginate a group or Comic section."""
-        num_pages, total_count, model = page_counts
-        paginator = Paginator(qs, max_obj_per_page, orphans=self._ORPHANS)
-        page = self.kwargs.get("page", 1)
+        orphans = 0 if self.model_group == "f" or self.params.get("q") else 5
+        paginator = Paginator(qs, MAX_OBJ_PER_PAGE, orphans=orphans)
         try:
             qs = paginator.page(page).object_list
-            num_pages = max(num_pages, paginator.num_pages)
-            total_count += paginator.count
         except EmptyPage:
-            if page < 1 or page > paginator.num_pages:
-                self._page_out_out_bounds(page, paginator.num_pages)
-            model_name = self.model.__name__ if self.model else "NO_MODEL"
-            LOG.warning(f"No {model_name}s on page {page}")
-            model.objects.none()
+            if model != Folder:
+                model_name = self.model.__name__ if self.model else "NO_MODEL"
+                LOG.warning(f"No {model_name}s on page {page}")
+            qs = model.objects.none()
 
-        return qs, num_pages, total_count
+        return qs
+
+    def _paginate_groups(self, group_qs, total_group_count):
+        """Paginate the group object list before books."""
+        if total_group_count:
+            page = self.kwargs.get("page", 1)
+            page_group_qs = self._paginate_section(self.model, group_qs, page)
+        else:
+            page_group_qs = self.model.objects.none()  # type: ignore
+        return page_group_qs
+
+    def _paginate_books(self, book_qs, total_group_count, page_obj_count):
+        """Paginate the book object list based on how many group/folders are showing."""
+        if page_obj_count >= MAX_OBJ_PER_PAGE:
+            # No books for this page
+            page_book_qs = Comic.objects.none()
+        else:
+            group_remainder = total_group_count % MAX_OBJ_PER_PAGE
+            if page_obj_count:
+                # There are books after the groups on the same page
+                # Manually add books without the paginator
+                book_limit = MAX_OBJ_PER_PAGE - group_remainder
+                page_book_qs = book_qs[:book_limit]
+            else:
+                # There are books after the groups on a new page
+                if group_remainder:
+                    book_offset = MAX_OBJ_PER_PAGE - group_remainder
+                    page_book_qs = book_qs[book_offset:]
+                else:
+                    page_book_qs = book_qs
+
+                num_group_and_mixed_pages = ceil(total_group_count / MAX_OBJ_PER_PAGE)
+                book_only_page = self.kwargs.get("page", 1) - num_group_and_mixed_pages
+                page_book_qs = self._paginate_section(
+                    Comic, page_book_qs, book_only_page
+                )
+        return page_book_qs
 
     def _paginate(self, group_qs, book_qs):
-        """Paginate the queryset into a final object list."""
-        num_pages = 0
-        total_count = 0
+        """Paginate the queryset into a group and book object lists."""
+        page = self.kwargs.get("page", 1)
+        if page < 1:
+            self._page_out_of_bounds(1)
 
-        if group_qs.count():
-            page_counts = (num_pages, total_count, self.model)
-            group_qs, num_pages, total_count = self._paginate_section(
-                group_qs, self.MAX_OBJ_PER_PAGE, page_counts
-            )
+        page_obj_count = 0
 
-        if book_qs.count():
-            book_max_obj_per_page = max(0, self.MAX_OBJ_PER_PAGE - group_qs.count())
-            page_counts = (num_pages, total_count, Comic)
-            group_qs, num_pages, total_count = self._paginate_section(
-                group_qs, book_max_obj_per_page, page_counts
-            )
+        group_count = group_qs.count()
+        book_count = book_qs.count()
 
-        return group_qs, book_qs, num_pages, total_count
+        num_pages = ceil((group_count + book_count) / MAX_OBJ_PER_PAGE)
+        if page > num_pages:
+            self._page_out_of_bounds(num_pages)
+
+        page_group_qs = self._paginate_groups(group_qs, group_count)
+        page_obj_count += page_group_qs.count()
+        page_book_qs = self._paginate_books(book_qs, group_count, page_obj_count)
+        page_obj_count += page_book_qs.count()
+
+        return page_group_qs, page_book_qs, num_pages, page_obj_count
 
     def get_object(self):
         """Validate settings and get the querysets."""
@@ -333,7 +387,7 @@ class BrowserView(BrowserAnnotationsView):
         self.set_rel_prefix(self.model)
         self._set_group_instance()  # Placed up here to invalidate earlier
         # Create the main query with the filters
-        search_scores: dict = self.get_search_scores()
+        search_scores: dict | None = self.get_search_scores()
         group = self.kwargs.get("group")
 
         group_qs = self._get_group_queryset(search_scores)
@@ -356,14 +410,12 @@ class BrowserView(BrowserAnnotationsView):
         else:
             up_route = {}
 
-        efv_flag = AdminFlag.objects.only("on").get(
-            key=AdminFlag.FlagChoices.FOLDER_VIEW.value
-        )
-
         libraries_exist = Library.objects.exists()
 
         # runs obj list query twice :/
-        issue_max = book_qs.only("issue").aggregate(Max("issue"))["issue__max"]
+        issue_number_max = book_qs.only("issue_number").aggregate(Max("issue_number"))[
+            "issue_number__max"
+        ]
 
         covers_timestamp = int(
             Timestamp.objects.get(
@@ -379,10 +431,10 @@ class BrowserView(BrowserAnnotationsView):
                 "model_group": self.model_group,
                 "groups": group_qs,
                 "books": book_qs,
-                "issue_max": issue_max,
+                "issue_number_max": issue_number_max,
                 "num_pages": num_pages,
                 "total_count": total_count,
-                "admin_flags": {"folder_view": efv_flag.on},
+                "admin_flags": self.admin_flags,
                 "libraries_exist": libraries_exist,
                 "covers_timestamp": covers_timestamp,
             }
@@ -434,7 +486,7 @@ class BrowserView(BrowserAnnotationsView):
 
     def _raise_redirect(self, route_mask, reason, settings_mask=None):
         """Redirect the client to a valid group url."""
-        route = deepcopy(dict(self._DEFAULT_ROUTE))
+        route = deepcopy(dict(self.DEFAULT_ROUTE))
         route["params"].update(route_mask)  # type: ignore
         settings = deepcopy(self.params)
         if settings_mask:
@@ -505,18 +557,23 @@ class BrowserView(BrowserAnnotationsView):
         page = self.kwargs.get("page", 1)
         self.params["route"] = {"group": group, "pk": pk, "page": page}
 
+    def _set_admin_flags(self):
+        """Set browser relevant admin flags."""
+        admin_pairs = AdminFlag.objects.filter(
+            key__in=_ADMIN_FLAG_VALUE_KEY_MAP.keys()
+        ).values_list("key", "on")
+        admin_flags = {}
+        for key, on in admin_pairs:
+            export_key = _ADMIN_FLAG_VALUE_KEY_MAP[key]
+            admin_flags[export_key] = on
+        self.admin_flags = MappingProxyType(admin_flags)
+
     def validate_settings(self):
         """Validate group and top group settings."""
         group = self.kwargs.get("group")
         self.set_order_key()
-        enable_folder_view = False
-        if group == self.FOLDER_GROUP or self.order_key == "path":
-            key = AdminFlag.FlagChoices.FOLDER_VIEW.value
-            try:
-                enable_folder_view = AdminFlag.objects.only("on").get(key=key).on
-            except Exception as err:
-                title = CHOICES["admin"]["adminFlags"].get(key)
-                LOG.warning(f"Getting {title} AdminFlag: {err}")
+        self._set_admin_flags()
+        enable_folder_view = self.admin_flags["folder_view"]
 
         if group == self.FOLDER_GROUP:
             self._validate_folder_settings(enable_folder_view)
@@ -535,7 +592,7 @@ class BrowserView(BrowserAnnotationsView):
             self._raise_redirect(route_changes, reason, settings_mask)
 
     @extend_schema(request=BrowserAnnotationsView.input_serializer_class)
-    def get(self, *args, **kwargs):
+    def get(self, *_args, **_kwargs):
         """Get browser settings."""
         self.parse_params()
         self.validate_settings()
