@@ -1,7 +1,8 @@
 """Search Filters Methods."""
-from django.db.models import Q
-from haystack.query import SearchQuerySet
 
+from django.db.models import Q
+
+from codex._vendor.haystack.query import SearchQuerySet
 from codex.logger.logging import get_logger
 from codex.models import Comic
 
@@ -11,14 +12,10 @@ LOG = get_logger(__name__)
 class SearchFilterMixin:
     """Search Filters Methods."""
 
-    def get_search_scores(self) -> dict:
+    def get_search_scores(self) -> dict | None:
         """Perform the search and return the scores as a dict."""
         search_scores = {}
         text = self.params.get("q", "")  # type: ignore
-        if not text:
-            # for opds 2
-            text = self.params.get("query", "")  # type: ignore
-        text = text.strip()
         if not text:
             return search_scores
 
@@ -29,9 +26,10 @@ class SearchFilterMixin:
                 search_scores[comic_score["pk"]] = comic_score["score"]
         except MemoryError:
             LOG.warning("Search engine needs more memory, results truncated.")
-        except Exception as exc:
-            LOG.warning("While searching:")
-            LOG.exception(exc)
+        except Exception:
+            LOG.exception("While Searching")
+        if not search_scores:
+            return None
         return search_scores
 
     def _get_search_query_filter(self, model, search_scores: dict):
