@@ -1,4 +1,5 @@
 """Frontend views."""
+
 from typing import ClassVar
 
 from rest_framework.renderers import TemplateHTMLRenderer
@@ -10,10 +11,10 @@ from codex.views.session import BrowserSessionViewBase
 class IndexView(BrowserSessionViewBase):
     """The main app."""
 
-    renderer_classes: ClassVar[list] = [TemplateHTMLRenderer]
+    renderer_classes: ClassVar[list] = [TemplateHTMLRenderer]  # type: ignore
     template_name = "index.html"
 
-    def get(self, *args, **kwargs):
+    def get(self, *_args, **_kwargs):
         """Get the app index page."""
         last_route = self.get_from_session("route")
         extra_context = {"last_route": last_route}
